==> mitm_tooling-0.5.0-py3-none-any.whl: mitm_tooling/transformation/superset/common.py <==
from typing import Type

import pydantic
import sqlalchemy as sa
from pydantic import AnyUrl, ConfigDict

from mitm_tooling.representation import SchemaName, Header
from mitm_tooling.representation.sql_representation import SQL_REPRESENTATION_DEFAULT_SCHEMA
from mitm_tooling.utilities.io_utils import FilePath
from mitm_tooling.utilities.sql_utils import create_sa_engine, dialect_cls_from_url, any_url_into_sa_url
from .definitions import StrUrl
from ...definition import MITM

SQLiteFileOrEngine = FilePath | sa.Engine


class DBConnectionInfo(pydantic.BaseModel):
    model_config = ConfigDict(arbitrary_types_allowed=True)

    sql_alchemy_uri: StrUrl
    explicit_db_name: str | None = None
    schema_name: SchemaName = SQL_REPRESENTATION_DEFAULT_SCHEMA
    catalog: str | None = None  # for future use

    @property
    def sa_url(self) -> sa.URL:
        return any_url_into_sa_url(self.sql_alchemy_uri)

    @property
    def db_name_in_uri(self) -> str:
        return self.sa_url.database

    @property
    def db_name(self) -> str:
        return self.explicit_db_name or self.db_name_in_uri

    @property
    def dialect_cls(self) -> Type[sa.engine.Dialect]:
        return dialect_cls_from_url(self.sql_alchemy_uri)

class MitMDatasetInfo(pydantic.BaseModel):
    dataset_name: str
    mitm: MITM

    @classmethod
    def named_header(cls, name:str, header: Header):
        return cls(dataset_name=name, mitm=header.mitm)

def _mk_engine(arg: SQLiteFileOrEngine) -> sa.Engine:
    if isinstance(arg, sa.Engine):
        return arg
    else:
        return create_sa_engine(AnyUrl(f'sqlite:///{str(arg)}'), poolclass=sa.pool.StaticPool)

==> mitm_tooling-0.8.1-py3-none-any.whl: mitm_tooling/transformation/superset/common.py <==
from typing import Type

import pydantic
import sqlalchemy as sa
from pydantic import AnyUrl, ConfigDict

from mitm_tooling.representation.intermediate import Header
from mitm_tooling.representation.sql import SQL_REPRESENTATION_DEFAULT_SCHEMA, SchemaName
from mitm_tooling.utilities.sql_utils import create_sa_engine, dialect_cls_from_url, any_url_into_sa_url, \
    SQLiteFileOrEngine
from .definitions import StrUrl
from ...definition import MITM


class DBConnectionInfo(pydantic.BaseModel):
    model_config = ConfigDict(arbitrary_types_allowed=True)

    sql_alchemy_uri: StrUrl
    explicit_db_name: str | None = None
    schema_name: SchemaName = SQL_REPRESENTATION_DEFAULT_SCHEMA
    catalog: str | None = None  # for future use

    @property
    def sa_url(self) -> sa.URL:
        return any_url_into_sa_url(self.sql_alchemy_uri)

    @property
    def db_name_in_uri(self) -> str:
        return self.sa_url.database

    @property
    def db_name(self) -> str:
        return self.explicit_db_name or self.db_name_in_uri

    @property
    def dialect_cls(self) -> Type[sa.engine.Dialect]:
        return dialect_cls_from_url(self.sql_alchemy_uri)


class MitMDatasetInfo(pydantic.BaseModel):
    dataset_name: str
    mitm: MITM
    header: Header | None = None

    @classmethod
    def from_header(cls, name: str, header: Header):
        return cls(dataset_name=name, mitm=header.mitm, header=header)


def _mk_sqlite_engine(arg: SQLiteFileOrEngine) -> sa.Engine:
    if isinstance(arg, sa.Engine):
        return arg
    else:
        return create_sa_engine(AnyUrl(f'sqlite:///{str(arg)}'), poolclass=sa.pool.StaticPool)
